/*
 * getdefaults.c : Read defaults from .xtrekrc file here <isae@iastate.edu>
 */

#ifdef MOO

#include "copyright2.h"
#include <stdio.h>
#include "Wlib.h"
#include "defs.h"
#include "struct.h"
#include "data.h"

extern int      updateSpeed;	/* from option.c */
extern int      oldBless;	/* from main.c */
#ifdef RECORD
extern char    *recordFileName;	/* from main.c */
#endif
#ifdef LOGMESG
extern char    *logFileName;	/* from main.c */
#endif

readDefaults()
{
   printf("Reading default values ...\n");

   /* Read keymap */
   initkeymap();

   /* Boolean defaults */
   namemode = booleanDefault("showPlanetNames", namemode);
   showShields = booleanDefault("showShields", showShields);
   showStats = booleanDefault("showStats", showStats);
   keeppeace = booleanDefault("keepPeace", keeppeace);
   reportKills = booleanDefault("reportKills", reportKills);
#ifdef MOOBITMAPS
   myPlanetBitmap = booleanDefault("newPlanetBitmaps", myPlanetBitmap);
#endif				/* MOOBITMAPS */
   showTractorPressor = booleanDefault("showTractorPressor", showTractorPressor);
   fillTriangle = booleanDefault("fillTriangle", fillTriangle);
   continueTractor = booleanDefault("continueTractor", continueTractor);
   extraBorder = booleanDefault("extraAlertBorder", extraBorder);
#ifdef NETSTAT
   netstat = booleanDefault("netstats", netstat);
#endif
#ifdef NOWARP
   warp = booleanDefault("warp", warp);
#endif
   tryUdp = booleanDefault("tryUdp", tryUdp);
   udpSequenceChk = booleanDefault("udpSequenceCheck", udpSequenceChk);

   if (booleanDefault("galacticFrequent", 1))
      mapmode = 2;

#ifdef LOGMESG
   logMess = booleanDefault("logMessage", logMess);
#endif
#ifdef VSHIELD_BITMAPS
   VShieldBitmaps = booleanDefault("varyShields", VShieldBitmaps);
#endif

   use_msgw = booleanDefault("useMsgw", use_msgw);
   phas_msgi = booleanDefault("phaserMsgI", phas_msgi);

#ifdef RECORD
   /* My attempt to control the recorder during the game */
   recordGame = booleanDefault("recordGame", recordGame);
#endif

   /* Numeric defaults */
   showlocal = intDefault("showLocal", showlocal);
   if (showlocal > 2)
      showlocal = 2;
   showgalactic = intDefault("showGalactic", showgalactic);
   if (showgalactic > 2)
      showgalactic = 2;
   xtrekPort = intDefault("port", -1);
   showLock = intDefault("showLock", showLock);
   if (showlocal > 3)
      showlocal = 3;
   udpDebug = intDefault("udpDebug", udpDebug);
   udpClientSend = intDefault("udpClientSend", udpClientSend);
   udpClientRecv = intDefault("udpClientReceive", udpClientRecv);

#ifdef NETSTAT
   netstatfreq = intDefault("netstatfreq", netstatfreq);
   if (netstatfreq <= 0)
      netstatfreq = 1;
#endif

#ifdef SHORT_PACKETS
   tryShort = booleanDefault("tryShort", tryShort);
#endif

#ifdef EM
   sortPlayers = booleanDefault("sortplayers", sortPlayers);
#endif

#ifdef NEW_PL
   new_playerlist = booleanDefault("newPlayerList", new_playerlist);
#endif

   new_messages = booleanDefault("newMesgFlags", new_messages);

   tclock = intDefault("clock", tclock);

   /*
    * updateSpeed = abs(intDefault("updatesPerSecond", 5) - 10);
    */
   updateSpeed = intDefault("updatesPerSecond", 5);

#ifdef RECORD
   /* Get the record filename and message log file from .xtrekrc */
   if (recordFileName == NULL) {
      recordFileName = getdefault("recordFile");
      if (recordFileName != NULL) {
	 recordFile = fopen(recordFileName, "wb");
	 if (recordFile == NULL) {
	    perror(recordFileName);
	    exit(1);
	 }
	 recordGame = 1;	/* We want to record the game */
      } else
	 recordGame = 0;
   }
#endif
#ifdef FEATURE
   {
      char *macrokey_s = getdefault("macroKey");
      if(macrokey_s){
	 if(strcmp(macrokey_s, "TAB") == 0)
	    macrokey = 9;
	 else if(strcmp(macrokey_s, "ESC") == 0)
	    macrokey = 27;
	 else if(strcmp(macrokey_s, "ESC") == 0)
	    macrokey = 27;
	 else
	    macrokey = (int) macrokey_s[0];
      }
   }
#endif
      
   sendOptionsPacket();

   printf("Done reading default values ...\n");
}

/* totally re-do the defaults! */
ReReadDefaults()
{

   extern char    *defaultsFile;
   FreeDefaults();
   initDefaults(defaultsFile);
   readDefaults();
}

#endif	/* MOO */


#ifdef LOGMESG
/* log the message sent here into a file */
LogMessage(message)
    char           *message;
{

   if (!logMess)
      return;

   if (logFile == NULL) {
      /*
       * need to open the logfile! if (logFileName == NULL) logFileName =
       * getdefault("logFile");
       * 
      /* If we don't get it from rc file, we use the default filename. Note
       * we won't log the messages unless logMess==1 (can be toggled via
       * keyboard) <isae>
       */

      if (logFileName == NULL)
	 logFileName = DEFAULT_RECORDFILE;
      logFile = fopen(logFileName, "w+");
      if (logFile == NULL) {
	 fprintf(stderr, "Can't open message logfile!\n");
	 perror(logFileName);
	 fprintf(stderr, "no messages logging being done!\n");
	 return;
      }
   }
   fprintf(logFile, "%s\n", message);
}
#endif
